==> haskell-summoner-2.0.1.1-538-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-summoner.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 summoner
version:              2.0.1.1
visibility:           public
id:                   summoner-2.0.1.1-BOuOLM6OOzm6ZIpcZMlGSc
key:                  summoner-2.0.1.1-BOuOLM6OOzm6ZIpcZMlGSc
license:              MPL-2.0
copyright:            2018-2020 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
stability:            stable
homepage:             https://github.com/kowainik/summoner
synopsis:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects.

description:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects.
    See [README.md](https://github.com/kowainik/summoner#-summoner) for details.

category:             CLI, CLI Tool, Development
abi:                  955ec0e55c08aebf307d4d6ef3afc8ff
exposed:              True
exposed-modules:
    Summoner Summoner.CLI Summoner.Config Summoner.CustomPrelude
    Summoner.Decision Summoner.Default Summoner.GhcVer Summoner.License
    Summoner.Mode Summoner.Project Summoner.Question Summoner.Settings
    Summoner.Source Summoner.Template Summoner.Template.Cabal
    Summoner.Template.Doc Summoner.Template.GitHub
    Summoner.Template.Haskell Summoner.Template.Script
    Summoner.Template.Stack Summoner.Text Summoner.Tree

hidden-modules:       Paths_summoner
import-dirs:          /usr/lib/ghc-9.4.8/site-local/summoner-2.0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/summoner-2.0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/summoner-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-summoner
hs-libraries:         HSsummoner-2.0.1.1-BOuOLM6OOzm6ZIpcZMlGSc
depends:
    base-4.17.2.1 relude-1.2.1.0-HZDfZenzd1UK2d2FuJbFIx
    aeson-2.1.2.1-8pX4IwvbwpcwXiIiReOQk
    colourista-0.1.0.2-CAia5h4y5A42BQMz0dRoma containers-0.6.7
    directory-1.3.7.1 filepath-1.4.2.2
    generic-data-1.1.0.0-GyZxPvb8qWBDNVKUj0hf5A
    gitrev-1.3.1-H2G7FNkm0RTIvLJOJ6VmrQ
    neat-interpolation-0.5.1.4-Alk2f7BiIHUJPi54I6urfr
    optparse-applicative-0.17.1.0-3m15PZJ9R8tLZfnW85Yn0z
    process-1.6.18.0 shellmet-0.0.5.0-Ibc4PENstt48wvwVXXnGNw text-2.0.2
    time-1.12.2 tomland-1.3.3.3-LLYl6ADQ4YC6CVbONV4iCf
    validation-selective-0.2.0.0-4qQwLKcy3g5KQeSibvkBPe

haddock-interfaces:   /usr/share/doc/haskell-summoner/html/summoner.haddock
haddock-html:         /usr/share/doc/haskell-summoner/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-summoner-2.0.1.1-539-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-summoner.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 summoner
version:              2.0.1.1
visibility:           public
id:                   summoner-2.0.1.1-CJF0EOOpyjK1IeAhEskjzC
key:                  summoner-2.0.1.1-CJF0EOOpyjK1IeAhEskjzC
license:              MPL-2.0
copyright:            2018-2020 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
stability:            stable
homepage:             https://github.com/kowainik/summoner
synopsis:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects.

description:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects.
    See [README.md](https://github.com/kowainik/summoner#-summoner) for details.

category:             CLI, CLI Tool, Development
abi:                  91220a9a189ad57095b9b7f8a5e1ae18
exposed:              True
exposed-modules:
    Summoner Summoner.CLI Summoner.Config Summoner.CustomPrelude
    Summoner.Decision Summoner.Default Summoner.GhcVer Summoner.License
    Summoner.Mode Summoner.Project Summoner.Question Summoner.Settings
    Summoner.Source Summoner.Template Summoner.Template.Cabal
    Summoner.Template.Doc Summoner.Template.GitHub
    Summoner.Template.Haskell Summoner.Template.Script
    Summoner.Template.Stack Summoner.Text Summoner.Tree

hidden-modules:       Paths_summoner
import-dirs:          /usr/lib/ghc-9.4.8/site-local/summoner-2.0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/summoner-2.0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/summoner-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-summoner
hs-libraries:         HSsummoner-2.0.1.1-CJF0EOOpyjK1IeAhEskjzC
depends:
    base-4.17.2.1 relude-1.2.1.0-2GWlvgIGOz8IpJ3nTffyo7
    aeson-2.1.2.1-HgTvGelKFeMCs4MoB4HQQ3
    colourista-0.1.0.2-4weLdleEGLoBRMf6wkD8Tw containers-0.6.7
    directory-1.3.7.1 filepath-1.4.2.2
    generic-data-1.1.0.0-9VoUEwZqQMeC3PMnTQRBZU
    gitrev-1.3.1-H2G7FNkm0RTIvLJOJ6VmrQ
    neat-interpolation-0.5.1.4-I8klY5CFRbnvzjptoPDpV
    optparse-applicative-0.17.1.0-3m15PZJ9R8tLZfnW85Yn0z
    process-1.6.18.0 shellmet-0.0.5.0-CDzX8gh9ost9pKemzFOvvG text-2.0.2
    time-1.12.2 tomland-1.3.3.3-KSqic7PnIem84B4RpY5DZW
    validation-selective-0.2.0.0-5CEqOwOQkEv6T5jt9CPWVe

haddock-interfaces:   /usr/share/doc/haskell-summoner/html/summoner.haddock
haddock-html:         /usr/share/doc/haskell-summoner/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
